### Internationalization for react components

[![npm](https://img.shields.io/npm/v/react-localized.svg?maxAge=2592000)](https://www.npmjs.com/package/react-localized)

### Features

- based on gettext format
- plural forms support
- current locale stored in redux
- translations can be generated by editor (Poedit) automatically
- provides webpack loader for the .po files
- allows you to extend locale data
- allows you to split locales data and app bundle with webpack dynamic import

### Installation
```
yarn add react-localized
```
### Usage

#### Configure webpack

```javascript
module: {
  rules: [
    {
      test: /\.po$/,
      use: 'react-localized/message-loader'
    }
  ]
}
```

#### Create locales

Use Poedit to create messages. It can parse your source code.

```javascript
import format from 'date-fns/format'
import locale from 'date-fns/locale/ru'
import { createLocaleData } from 'react-localized'
import messages from './ru.po'

// you can create your custom locale data
// it will be passed as `i18n` prop to localized components
const customLocaleData = {
  formatDate: (date, formatStr) => format(date, formatStr, { locale }),
  formats: {
    time: 'HH:mm',
    date: 'DD.MM.YYYY',
    dateTime: 'DD.MM.YYYY HH:mm',
    humanizedDate: 'DD MMMM YYYY',
  }
}

export default createLocaleData(messages, customLocaleData)
```

#### Configure store

```javascript
import { reducer as localeReducer } from 'react-localized'

createStore(combineReducers({
  locale: localeReducer
}))
```

#### Render LocaleProvider

```javascript
import { Provider as LocaleProvider } from 'react-localized'
import frenchLocaleData from './locales/fr'

const localeData = {
  fr: frenchLocaleData,
  // you can pass function which returns promise
  // i.e. webpack dynamic import
  ru: () => import('./locales/ru').then(data => data.default)
}

export default () => (
  <LocaleProvider localeData={localeData}>
    ...
  </LocaleProvider>
)
```

#### Translate and use locale data

```javascript
import { localized } from 'react-localized'

@localized
export default class Example extends Component {
  static propTypes = {
    gettext: PropTypes.func.isRequired,
    ngettext: PropTypes.func.isRequired,
    // i18n can contain your custom locale data, e.g. date formatting functions
    // see example here https://github.com/fakundo/react-localized/blob/master/examples/locales/ru.js 
    i18n: PropTypes.object.isRequired
  }

  render() {
    const { gettext, ngettext, i18n } = this.props
    return (
      <div>
        { gettext('Hello, world!') } // Привет, мир!
        { gettext('My name is {0}', 'John') } // Мое имя John
        { gettext('My name is {0}', 'Anna') } // Мое имя Anna
        { ngettext('{0} apple', '{0} apples', 1, 1) } // 1 яблоко
        { ngettext('{0} apple', '{0} apples', 2, 2) } // 2 яблока
        { ngettext('{0} apple', '{0} apples', 10, 10) } // 10 яблок
        { i18n.formatDate(new Date(), i18n.formats.humanizedDate) } // 10 октября 2017
      </div>
    )
  }
}
```
